@@ -27,6 +27,15 @@
 
 */
 
+#include "ksysguard.h"
+#include "config-workspace.h"
+#include "HostConnector.h"
+#include "ProcessController.h"
+#include "SensorBrowser.h"
+#include "StyleEngine.h"
+#include "Workspace.h"
+#include "WorkSheet.h"
+
 #include <assert.h>
 #include <ctype.h>
 #include <fcntl.h>
@@ -34,39 +43,30 @@
 #include <stdlib.h>
 #include <unistd.h>
 
-#include <k4aboutdata.h>
-#include <kactioncollection.h>
-#include <kapplication.h>
-#include <KDBusService>
-#include <kdebug.h>
-#include <kedittoolbar.h>
-#include <kglobal.h>
-#include <kglobalsettings.h>
+#include <QApplication>
+#include <QCommandLineOption>
+#include <QCommandLineParser>
 #include <QIcon>
+#include <QLabel>
+#include <QSplitter>
+#include <QStatusBar>
+
+#include <KAboutData>
+#include <KActionCollection>
+#include <KDBusService>
+#include <KEditToolBar>
+#include <KFormat>
 #include <KLocalizedString>
-#include <kmessagebox.h>
+#include <KMessageBox>
+#include <KSharedConfig>
+#include <KStandardAction>
+#include <KToggleAction>
+#include <KUserTimestamp>
+#include <KWindowSystem>
+
 #include <ksgrd/SensorAgent.h>
 #include <ksgrd/SensorManager.h>
-#include <kstatusbar.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <kurl.h>
-#include <kwindowsystem.h>
-#include <QSplitter>
-
-#include <config-workspace.h>
-#include <KFormat>
-#include <QCommandLineParser>
-#include <QCommandLineOption>
-#include "SensorBrowser.h"
-#include "Workspace.h"
-#include "WorkSheet.h"
-#include "StyleEngine.h"
-#include "HostConnector.h"
-#include "ProcessController.h"
-#include "processui/ksysguardprocesslist.h"
-
-#include "ksysguard.h"
+#include <processui/ksysguardprocesslist.h>
 
 //Comment out to stop ksysguard from forking.  Good for debugging
 //#define FORK_KSYSGUARD
@@ -83,7 +83,6 @@ TopLevel::TopLevel()
 
   mSplitter = new QSplitter( this );
   mSplitter->setOrientation( Qt::Horizontal );
-  mSplitter->setOpaqueResize( KGlobalSettings::opaqueResize() );
   setCentralWidget( mSplitter );
 
   mSensorBrowser = 0;
@@ -223,13 +222,13 @@ void TopLevel::startSensorBrowserWidget()
 void TopLevel::showOnCurrentDesktop()
 {
   KWindowSystem::setOnDesktop( winId(), KWindowSystem::currentDesktop() );
-  kapp->updateUserTimestamp();
+  KUserTimestamp::updateUserTimestamp();
   KWindowSystem::forceActiveWindow( winId() );
 }
 
 void TopLevel::importWorkSheet( const QString &fileName )
 {
-  mWorkSpace->importWorkSheet( KUrl( fileName ) );
+  mWorkSpace->importWorkSheet(QUrl::fromLocalFile(fileName));
 }
 
 void TopLevel::removeWorkSheet( const QString &fileName )
@@ -536,7 +535,7 @@ extern "C" Q_DECL_EXPORT int kdemain( int argc, char** argv )
 
   KAboutData aboutData( QStringLiteral("ksysguard"), i18n( "System Monitor" ),
                         PROJECT_VERSION, i18n(Description), KAboutLicense::GPL,
-                        i18n( "(c) 1996-2008 The KDE System Monitor Developers" ) );
+                        i18n( "(c) 1996-2016 The KDE System Monitor Developers" ) );
   aboutData.setOrganizationDomain(QByteArray("kde.org"));
   aboutData.addAuthor( i18n("John Tapsell"), i18n("Current Maintainer"), QStringLiteral("john.tapsell@kde.org") );
   aboutData.addAuthor( i18n("Chris Schlaeger"), i18n("Previous Maintainer"), QStringLiteral("cs@kde.org") );
